import { type PropType } from "vue";
import { EChartsOption } from "echarts";
import { getNormalizedChart } from "@/utils/common";
import { dataSource } from "@/utils/common";
import { DataSourceType } from "@/enum";

export const basicBarProps = {
  width: {
    type: Number as PropType<number>,
    default: 400,
  },
  height: {
    type: Number as PropType<number>,
    default: 260,
  },
  dataSource,
  // 标题
  title: {
    type: Object as PropType<EChartsOption["title"]>,
  },
  // 图例
  legend: {
    type: Object as PropType<EChartsOption["legend"]>,
  },
  // 背景
  backgroundColor: {
    type: String as PropType<string>,
  },
  // 边框
  grid: {
    type: Object as PropType<EChartsOption["grid"]>,
  },
  // 提示框
  tooltip: {
    type: Object as PropType<EChartsOption["tooltip"]>,
  },
  // x轴数据
  xAxis: {
    type: Object as PropType<EChartsOption["xAxis"]>,
  },
  // y轴数据
  yAxis: {
    type: Object as PropType<EChartsOption["yAxis"]>,
  },
  // 折线
  series: {
    type: Array as PropType<EChartsOption["series"]>,
  },
  // 数据集
  dataset: {
    type: Object as PropType<EChartsOption["dataset"]>,
  },
  // color
  color: {
    type: Object as PropType<EChartsOption["color"]>
  }
};

const chartOptions = getNormalizedChart({
  title: {
    text: "柱状图标题",
  },
  xAxis: {
    data: ['轴标签A', '轴标签B', '轴标签C', '轴标签D']
  },
})

export const defaultPropsValue: EChartsOption = {
  // 组件容器默认属性
  container: {
    props: {
      width: 400,
      height: 260,
    },
  },
  // 图表默认属性
  props: {
    // 数据源
    dataSource: {
      sourceType: DataSourceType.STATIC,
      data: {
        xData: ['轴标签A', '轴标签B', '轴标签C', '轴标签D'],
        series: [
          {
            type: 'bar',
            name: '系列1',
            data: [89.3, 92.1, 94.4, 85.4]
          },
          {
            type: 'bar',
            name: '系列2',
            data: [95.8, 89.4, 91.2, 76.9]
          },
        ]
      },
    },
    ...chartOptions
  },
};
