import type { EChartsOption } from "echarts";
import { computed, watch, ref } from "vue";
import { omit, defaultsDeep } from 'lodash';
import { useRequest } from "vue-hooks-plus";
import { DataSourceType } from '@/enum';

export const useChartOptions = (chartProps: Record<string, any>) => {
  const dataSource = chartProps.dataSource || {}
  const xAxis = ref<EChartsOption["xAxis"]>({data: dataSource?.data?.xData});
  const yAxis = ref<EChartsOption["yAxis"]>({data: dataSource?.data?.yData});
  const series = ref<EChartsOption["series"]>(dataSource?.data?.series);

  // 请求数据
  const { run, refresh, cancel, data, loading} = useRequest(chartProps.dataSource.url, {
    defaultParams: chartProps.dataSource.params,
    manual: true,
    pollingInterval: (chartProps.dataSource?.refreshTime || 0) * 1000,
  });

  /* 初始请求 */
  if(chartProps.dataSource.sourceType === DataSourceType.API) {
    run();
  }

  watch(
    () => data.value,
    (val) => {
      if(val && chartProps.dataSource.sourceType === DataSourceType.API) {
        const { xData, yData, series } = data.value as any;
        // TODO 数据处理成通用格式
        xAxis.value = {data: xData};
        yAxis.value = {data: yData};
        series.value = series;
      }
    },{
      deep: true
    }
  )

  watch(
    () => chartProps.dataSource,
    (val) => {
      if(val === DataSourceType.API) {
        refresh();
      } else {
        cancel();
        const dataSource = chartProps.dataSource || {};
        xAxis.value = {data: dataSource?.data?.xData};
        yAxis.value = {data: dataSource?.data?.yData};
        series.value = dataSource?.data?.series;
      }
    },
    {
      deep: true
    }
  )

  const options = computed((): EChartsOption => {
    const opt = omit(chartProps, ['width', 'height', 'dataSource']) as EChartsOption;
    
    return defaultsDeep({
      xAxis: xAxis.value,
      yAxis: yAxis.value,
      series: series.value,
    }, opt);
  });

  return {
    options,
    loading
  }
}